#
# spec file for package ibm-dlpar-utils-release (Version 12)
#
# Copyright (c) 2020 SUSE.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugzilla.novell.com/
#


# ======================================================================
# Product definition macros:
#
# - Product definition is the /etc/products.d .prod file created in the
#   %%install section.
#
# - The -release package ships the product definition, but some of the
#   product data must be exposed in the release packages provides.
#
# - The macros in this section define those product properties which must
#   be shared between -release package and product definition. Inconsistencies
#   often do not prevent the installation but may affect later updates.
#
# - Some of the products data exposed in the in the release packages provides,
#   need to be %%-escaped. Technically every datum that does not match rpms
#   requirement for a valid 'version-release' string. For those data I'll
#   define %%macro and %%macro_pcescaped. If you change one value adapt the
#   other accordingly.
#
# - At least for major releases check whether the hardcoded product data in
#   the %%install section still apply.

# Per convention the %%product name will be used a stem for the -release
# package and the -prod file
%define         product ibm-dlpar-utils

# Decide: The products version and release often follows the release package.
# In this case use the -release packages %%{version} and %%{release}. But
# it is possible to maintain different v-r for product and -release package.
# In this case the products v-r would be defined here.
%define         productversion %{version}
%define         productrelease %{release}

# A short name for the product used in tables etc. if the summary would be too long.
# Product summary and description are taken from the -release package. So usually
# the -release packages summary/description and the products <summary>/<description>
# tags provide the same text.
%define         productlabel IBMDLPU12
%define         productlabel_pcescaped %{productlabel}

# The date when this Product goes out of support. A missing value indicates
# that there will be no EOL, while an empty/invalid value indicates that
# there will be an EOL date, but it's not yet known.
%define         productendoflife 2024-10-31
%define         productendoflifel_pcescaped 2024%2D10%2D31

# PLEASE CHECK: Original value was cpe:/o:suse:ibm-dlpar-utils:12
#               I adapted the product name AND changed vendor from suse to ibm
%define         productcpeid cpe:/o:suse:ibm-dlpar-utils:12
%define         productcpeid_pcescaped cpe%3A%2Fo%3Asuse%3Aibm%2Ddlpar%2Dutils%3A12

# PLEASE CHECK: I suppose there should be a different URL used to report issues.
#
%define         producturlbugtracker https://bugzilla.novell.com
%define         producturlbugtracker_pcescaped https%3A%2F%2Fbugzilla.novell.com%2F

# Don't know the exact purpose. Zypp just forwards the value.
# In case the product data would also define a value for <register><target/>,
# It should be exposed in the -release package provides as product-register-flavor()
%define         productregisterflavor extension
%define         productregisterflavor_pcescaped %{productregisterflavor}
# ----------------------------------------------------------------------


Name:           %{product}-release
Summary:        IBM DLPAR Utils for SLE 12
Version:        12
Release:        2
License:        BSD-3-Clause
Group:          System/Fhs
Vendor:         IBM

Provides:       %name-%version
# ======================================================================
# Product indicator provides (mandatory and important):
Provides:       product() = %{product}
Provides:       product(%{product}) = %{productversion}-%{productrelease}
# Additional product data exposed in the -release package:
Provides:       product-label() = %{productlabel_pcescaped}
Provides:       product-endoflife() = %{productendoflife_pcescaped}
Provides:       product-cpeid() = %{productcpeid_pcescaped}
Provides:       product-url(bugtracker) = %{producturlbugtracker_pcescaped}
Provides:       product-register-flavor() = %{productregisterflavor_pcescaped}
# ----------------------------------------------------------------------

# Below here, the 'ordinary' product and -release package dependencies:
Requires:       product_flavor(%{product})
Requires:       product(SUSE_SLE) >= 12

AutoReqProv:    on
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
IBM DLPAR Utils for SLE 12


%package POOL
License:        BSD-3-Clause
Group:          System/Fhs
Provides:       flavor(POOL)
Provides:       product_flavor()
Provides:       product_flavor(%{product}) = %{productversion}-%{productrelease}
Summary:        IBM DLPAR Utils for SLE 12

%description POOL
IBM DLPAR Utils for SLE 12

%files POOL
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{name}-POOL



%prep

%build


%install
mkdir -p $RPM_BUILD_ROOT/etc/products.d
cat >$RPM_BUILD_ROOT/etc/products.d/%{product}.prod << EOF
<?xml version="1.0" encoding="UTF-8"?>
<product schemeversion="0">
  <vendor>%{vendor}</vendor>
  <name>%{product}</name>
  <version>%{productversion}</version>
  <release>%{productrelease}</release>
  <arch>%{_target_cpu}</arch>
  <shortsummary>%{productlabel}</shortsummary>
  <endoflife>%{productendoflife}</endoflife>
  <cpeid>%{productcpeid}</cpeid>
  <summary>IBM DLPAR Utils for SLE 12</summary>
  <description>IBM DLPAR Utils for SLE 12</description>
  <productline>%{product}</productline>
  <baseversion>12</baseversion>
  <patchlevel>0</patchlevel>
  <register>
    <target/>
    <flavor>%{productregisterflavor}</flavor>
    <updates>
    </updates>
  </register>
  <upgrades/>
  <urls>
    <url name="bugtracker">%{producturlbugtracker}</url>
  </urls>
  <buildconfig>
    <producttheme>SLES</producttheme>
  </buildconfig>
  <installconfig>
    <defaultlang>en_US</defaultlang>
    <releasepackage name="%{name}" flag="EQ" version="%{version}" release="%{release}"/>
    <distribution>SUSE_SLE</distribution>
  </installconfig>
  <runtimeconfig/>
  <productdependency relationship="requires" name="SUSE_SLE" baseversion="12" patchlevel="0" flag="GE"/>
</product>

EOF

mkdir -p $RPM_BUILD_ROOT/%{_defaultdocdir}/%{name}-POOL
cat >$RPM_BUILD_ROOT/%{_defaultdocdir}/%{name}-POOL/README << EOF
This package only exists for providing the product flavor 'POOL'.

EOF



%clean
rm -rf %buildroot

%files
%defattr(644,root,root,755)
%dir /etc/products.d
/etc/products.d/*.prod

%changelog
